pub struct DMSCPrometheusExporter { /* private fields */ }Expand description
Prometheus exporter for managing metrics and generating Grafana dashboards.
This struct provides methods for registering and updating Prometheus metrics, as well as generating Grafana dashboards from these metrics.
Implementations
Sourceimpl DMSCPrometheusExporter
impl DMSCPrometheusExporter
Sourcepub fn new() -> DMSCResult<Self>
pub fn new() -> DMSCResult<Self>
Creates a new Prometheus exporter instance.
Returns
A new DMSCPrometheusExporter instance wrapped in DMSCResult
Sourcepub fn register_counter(&self, name: &str, help: &str) -> DMSCResult<()>
pub fn register_counter(&self, name: &str, help: &str) -> DMSCResult<()>
Sourcepub fn increment_counter(&self, name: &str, value: f64) -> DMSCResult<()>
pub fn increment_counter(&self, name: &str, value: f64) -> DMSCResult<()>
Sourcepub fn register_gauge(&self, name: &str, help: &str) -> DMSCResult<()>
pub fn register_gauge(&self, name: &str, help: &str) -> DMSCResult<()>
Sourcepub fn register_histogram(
&self,
name: &str,
help: &str,
buckets: Vec<f64>,
) -> DMSCResult<()>
pub fn register_histogram( &self, name: &str, help: &str, buckets: Vec<f64>, ) -> DMSCResult<()>
Sourcepub fn observe_histogram(&self, name: &str, value: f64) -> DMSCResult<()>
pub fn observe_histogram(&self, name: &str, value: f64) -> DMSCResult<()>
Sourcepub fn render(&self) -> DMSCResult<String>
pub fn render(&self) -> DMSCResult<String>
Renders all metrics in Prometheus text format.
Returns
A string containing all metrics in Prometheus text format wrapped in DMSCResult
Sourcepub fn add_counter_panel(
&self,
dashboard: &mut DMSCGrafanaDashboard,
title: &str,
query: &str,
) -> DMSCResult<()>
pub fn add_counter_panel( &self, dashboard: &mut DMSCGrafanaDashboard, title: &str, query: &str, ) -> DMSCResult<()>
Sourcepub fn add_gauge_panel(
&self,
dashboard: &mut DMSCGrafanaDashboard,
title: &str,
query: &str,
) -> DMSCResult<()>
pub fn add_gauge_panel( &self, dashboard: &mut DMSCGrafanaDashboard, title: &str, query: &str, ) -> DMSCResult<()>
Sourcepub fn add_stat_panel(
&self,
dashboard: &mut DMSCGrafanaDashboard,
title: &str,
query: &str,
) -> DMSCResult<()>
pub fn add_stat_panel( &self, dashboard: &mut DMSCGrafanaDashboard, title: &str, query: &str, ) -> DMSCResult<()>
Sourcepub fn generate_dashboard(
&self,
title: &str,
) -> DMSCResult<DMSCGrafanaDashboard>
pub fn generate_dashboard( &self, title: &str, ) -> DMSCResult<DMSCGrafanaDashboard>
Sourcepub fn generate_default_dashboard(&self) -> DMSCResult<DMSCGrafanaDashboard>
pub fn generate_default_dashboard(&self) -> DMSCResult<DMSCGrafanaDashboard>
Generates a default Grafana dashboard with “DMSC Metrics Dashboard” title.
Returns
A default Grafana dashboard wrapped in DMSCResult